from setuptools import setup

setup(name='prob_distrok',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions'],
      author='Godfrey Tutu',
      author_email= 'godfrey_tutu@yahoo.com',
      zip_safe=False)
